-- ============================================================
--   Nom de la base   :  MCD_HOTEL                             
--   Nom de SGBD      :  ANSI Niveau 2                         
--   Date de cration :  16/01/2001  22:24                     
--   Copyright	      :  Frdric BROUARD
-- ============================================================

-- ============================================================
--   Table : T_CHAMBRE                                         
-- ============================================================
create table T_CHAMBRE
(
    CHB_ID               INTEGER               not null,
    CHB_NUMERO           SMALLINT              not null,
    CHB_ETAGE            CHAR(3)                       ,
    CHB_BAIN             NUMERIC(1)            not null
        default 0,
    CHB_DOUCHE           NUMERIC(1)            not null
        default 1,
    CHB_WC               NUMERIC(1)            not null
        default 1,
    CHB_COUCHAGE         SMALLINT              not null,
    CHB_POSTE_TEL        CHAR(3)                       ,
    primary key (CHB_ID)
);

-- ============================================================
--   Index : T_CHAMBRE_PK                                      
-- ============================================================
create unique index T_CHAMBRE_PK on T_CHAMBRE (CHB_ID asc);

-- ============================================================
--   Table : T_TARIF                                           
-- ============================================================
create table T_TARIF
(
    TRF_DATE_DEBUT       DATE                  not null,
    TRF_TAUX_TAXES       NUMERIC               not null,
    TRF_PETIT_DEJEUNE    NUMERIC(8,2)          not null,
    primary key (TRF_DATE_DEBUT)
);

-- ============================================================
--   Index : T_TARIF_PK                                        
-- ============================================================
create unique index T_TARIF_PK on T_TARIF (TRF_DATE_DEBUT asc);

-- ============================================================
--   Table : T_PLANNING                                        
-- ============================================================
create table T_PLANNING
(
    PLN_JOUR             DATE                  not null,
    primary key (PLN_JOUR)
);

-- ============================================================
--   Index : T_PLANNING_PK                                     
-- ============================================================
create unique index T_PLANNING_PK on T_PLANNING (PLN_JOUR asc);

-- ============================================================
--   Table : T_TITRE                                           
-- ============================================================
create table T_TITRE
(
    TIT_CODE             CHAR(8)               not null,
    TIT_LIBELLE          VARCHAR(32)           not null,
    primary key (TIT_CODE)
);

-- ============================================================
--   Index : T_TITRE_PK                                        
-- ============================================================
create unique index T_TITRE_PK on T_TITRE (TIT_CODE asc);

-- ============================================================
--   Table : T_TYPE                                            
-- ============================================================
create table T_TYPE
(
    TYP_CODE             CHAR(8)               not null,
    TYP_LIBELLE          VARCHAR(32)           not null,
    primary key (TYP_CODE)
);

-- ============================================================
--   Index : T_TYPE_PK                                         
-- ============================================================
create unique index T_TYPE_PK on T_TYPE (TYP_CODE asc);

-- ============================================================
--   Table : T_MODE_PAIEMENT                                   
-- ============================================================
create table T_MODE_PAIEMENT
(
    PMT_CODE             CHAR(8)               not null,
    PMT_LIBELLE          VARCHAR(64)           not null,
    primary key (PMT_CODE)
);

-- ============================================================
--   Index : T_MODE_PAIEMENT_PK                                
-- ============================================================
create unique index T_MODE_PAIEMENT_PK on T_MODE_PAIEMENT (PMT_CODE asc);

-- ============================================================
--   Table : T_CLIENT                                          
-- ============================================================
create table T_CLIENT
(
    CLI_ID               INTEGER               not null,
    TIT_CODE             CHAR(8)                       ,
    CLI_NOM              CHAR(32)              not null,
    CLI_PRENOM           VARCHAR(25)                   ,
    CLI_ENSEIGNE         VARCHAR(100)                  ,
    primary key (CLI_ID)
);

-- ============================================================
--   Index : T_CLIENT_PK                                       
-- ============================================================
create unique index T_CLIENT_PK on T_CLIENT (CLI_ID asc);

-- ============================================================
--   Index : L_CLI_TIT_FK                                      
-- ============================================================
create index L_CLI_TIT_FK on T_CLIENT (TIT_CODE asc);

-- ============================================================
--   Table : T_FACTURE                                         
-- ============================================================
create table T_FACTURE
(
    FAC_ID               INTEGER               not null,
    CLI_ID               INTEGER               not null,
    PMT_CODE             CHAR(8)                       ,
    FAC_DATE             DATE                  not null,
    FAC_PMT_DATE         DATE                          ,
    primary key (FAC_ID)
);

-- ============================================================
--   Index : T_FACTURE_PK                                      
-- ============================================================
create unique index T_FACTURE_PK on T_FACTURE (FAC_ID asc);

-- ============================================================
--   Index : L_FAC_CLI_FK                                      
-- ============================================================
create index L_FAC_CLI_FK on T_FACTURE (CLI_ID asc);

-- ============================================================
--   Index : TJ_FAC_PMT_FK                                     
-- ============================================================
create index TJ_FAC_PMT_FK on T_FACTURE (PMT_CODE asc);

-- ============================================================
--   Table : T_ADRESSE                                         
-- ============================================================
create table T_ADRESSE
(
    ADR_ID               INTEGER               not null,
    CLI_ID               INTEGER               not null,
    ADR_LIGNE1           VARCHAR(32)           not null,
    ADR_LIGNE2           VARCHAR(32)                   ,
    ADR_LIGNE3           VARCHAR(32)                   ,
    ADR_LIGNE4           VARCHAR(32)                   ,
    ADR_CP               CHAR(5)               not null,
    ADR_VILLE            CHAR(32)              not null,
    primary key (ADR_ID)
);

-- ============================================================
--   Index : T_ADRESSE_PK                                      
-- ============================================================
create unique index T_ADRESSE_PK on T_ADRESSE (ADR_ID asc);

-- ============================================================
--   Index : L_ADR_CLI_FK                                      
-- ============================================================
create index L_ADR_CLI_FK on T_ADRESSE (CLI_ID asc);

-- ============================================================
--   Table : T_TELEPHONE                                       
-- ============================================================
create table T_TELEPHONE
(
    TEL_ID               INTEGER               not null,
    CLI_ID               INTEGER               not null,
    TYP_CODE             CHAR(8)               not null,
    TEL_NUMERO           CHAR(20)              not null,
    TEL_LOCALISATION     VARCHAR(64)                   ,
    primary key (TEL_ID)
);

-- ============================================================
--   Index : T_TELEPHONE_PK                                    
-- ============================================================
create unique index T_TELEPHONE_PK on T_TELEPHONE (TEL_ID asc);

-- ============================================================
--   Index : L_TEL_CLI_FK                                      
-- ============================================================
create index L_TEL_CLI_FK on T_TELEPHONE (CLI_ID asc);

-- ============================================================
--   Index : L_TEL_TYP_FK                                      
-- ============================================================
create index L_TEL_TYP_FK on T_TELEPHONE (TYP_CODE asc);

-- ============================================================
--   Table : T_EMAIL                                           
-- ============================================================
create table T_EMAIL
(
    EML_ID               INTEGER               not null,
    CLI_ID               INTEGER               not null,
    EML_ADRESSE          VARCHAR(100)          not null,
    EML_LOCALISATION     VARCHAR(64)                   ,
    primary key (EML_ID)
);

-- ============================================================
--   Index : T_EMAIL_PK                                        
-- ============================================================
create unique index T_EMAIL_PK on T_EMAIL (EML_ID asc);

-- ============================================================
--   Index : L_EML_CLI_FK                                      
-- ============================================================
create index L_EML_CLI_FK on T_EMAIL (CLI_ID asc);

-- ============================================================
--   Table : T_LIGNE_FACTURE                                   
-- ============================================================
create table T_LIGNE_FACTURE
(
    LIF_ID               INTEGER               not null,
    FAC_ID               INTEGER               not null,
    LIF_QTE              NUMERIC               not null,
    LIF_REMISE_POURCENT  NUMERIC                       ,
    LIF_REMISE_MONTANT   NUMERIC(8,2)                  ,
    LIF_MONTANT          NUMERIC(8,2)          not null,
    LIF_TAUX_TVA         NUMERIC(8,2)          not null,
    primary key (LIF_ID)
);

-- ============================================================
--   Index : T_LIGNE_FACTURE_PK                                
-- ============================================================
create unique index T_LIGNE_FACTURE_PK on T_LIGNE_FACTURE (LIF_ID asc);

-- ============================================================
--   Index : L_LIF_FAC_FK                                      
-- ============================================================
create index L_LIF_FAC_FK on T_LIGNE_FACTURE (FAC_ID asc);

-- ============================================================
--   Table : TJ_TRF_CHB                                        
-- ============================================================
create table TJ_TRF_CHB
(
    CHB_ID               INTEGER               not null,
    TRF_DATE_DEBUT       DATE                  not null,
    TRF_CHB_PRIX         NUMERIC(8,2)          not null,
    primary key (CHB_ID, TRF_DATE_DEBUT)
);

-- ============================================================
--   Index : TJ_TRF_CHB_PK                                     
-- ============================================================
create unique index TJ_TRF_CHB_PK on TJ_TRF_CHB (CHB_ID asc, TRF_DATE_DEBUT asc);

-- ============================================================
--   Index : L_CHB_TRF_FK                                      
-- ============================================================
create index L_CHB_TRF_FK on TJ_TRF_CHB (CHB_ID asc);

-- ============================================================
--   Index : L_TRF_CHB_FK                                      
-- ============================================================
create index L_TRF_CHB_FK on TJ_TRF_CHB (TRF_DATE_DEBUT asc);

-- ============================================================
--   Table : TJ_CHB_PLN_CLI                                    
-- ============================================================
create table TJ_CHB_PLN_CLI
(
    CHB_ID               INTEGER               not null,
    PLN_JOUR             DATE                  not null,
    CLI_ID               INTEGER               not null,
    CHB_PLN_CLI_NB_PERS  SMALLINT              not null,
    CHB_PLN_CLI_RESERVE  NUMERIC(1)            not null
        default 0,
    CHB_PLN_CLI_OCCUPE   NUMERIC(1)            not null
        default 1,
    primary key (CHB_ID, PLN_JOUR)
);

-- ============================================================
--   Index : TJ_CHB_PLN_CLI_PK                                 
-- ============================================================
create unique index TJ_CHB_PLN_CLI_PK on TJ_CHB_PLN_CLI (CHB_ID asc, PLN_JOUR asc, CLI_ID asc);

-- ============================================================
--   Index : L_CHB_PLN_CLI_FK                                  
-- ============================================================
create index L_CHB_PLN_CLI_FK on TJ_CHB_PLN_CLI (CHB_ID asc);

-- ============================================================
--   Index : L_PLN_CHB_CLI_FK                                  
-- ============================================================
create index L_PLN_CHB_CLI_FK on TJ_CHB_PLN_CLI (PLN_JOUR asc);

-- ============================================================
--   Index : L_CLI_CHB_PLN_FK                                  
-- ============================================================
create index L_CLI_CHB_PLN_FK on TJ_CHB_PLN_CLI (CLI_ID asc);

